@@ -19,7 +19,7 @@ bad.dates <- data.frame(
   ),
   some.more.dates = c(
     "01 03 2015",
-    "02/05/00",
+    "2nd January 2010",
     "01/05/1990",
     "03-Dec-2012",
     "02 April 2020"
@@ -38,11 +38,14 @@ knitr::kable(fixed.dates)
 fix_date_char("01 02 2014")
 
 ## -----------------------------------------------------------------------------
-fix_date_char("7 de septiembre de 2014")
+fix_date_char("7 de septiembre del 2014")
 
 ## -----------------------------------------------------------------------------
 fix_date_char("01 02 2014", format = "mdy")
 
+## -----------------------------------------------------------------------------
+fix_date_char("July 4th, 1776")
+
 ## -----------------------------------------------------------------------------
 fix_date_char("1992")
 
